
#line 3 "scannerlexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 1
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yynoreturn yy_fatal_error (yyconst char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 160
#define YY_END_OF_BUFFER 161
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[1030] =
    {   0,
      161,  159,  160,    3,  159,  160,    1,  160,   45,  159,
      160,  159,  160,   20,  159,  160,   40,  159,  160,   42,
      159,  160,  159,  160,   29,  159,  160,   30,  159,  160,
       38,  159,  160,   36,  159,  160,   69,  159,  160,   37,
      159,  160,   35,  159,  160,   39,  159,  160,  152,  159,
      160,  152,  159,  160,   32,  159,  160,   31,  159,  160,
       47,  159,  160,   46,  159,  160,   48,  159,  160,   34,
      159,  160,  108,  149,  159,  160,  108,  149,  159,  160,
      108,  149,  159,  160,  108,  149,  159,  160,  108,  149,
      159,  160,   25,  159,  160,  159,  160,   27,  159,  160,

       41,  159,  160,  108,  149,  159,  160,  108,  149,  159,
      160,  108,  149,  159,  160,  108,  149,  159,  160,  108,
      149,  159,  160,  108,  149,  159,  160,  108,  149,  159,
      160,  108,  149,  159,  160,  108,  149,  159,  160,  108,
      149,  159,  160,  108,  149,  159,  160,  108,  149,  159,
      160,  108,  149,  159,  160,  108,  149,  159,  160,  108,
      149,  159,  160,  108,  149,  159,  160,   21,  159,  160,
       43,  159,  160,   23,  159,  160,   44,  159,  160,    3,
        1,   62,  157,   53,   24,   65,   55,  155,   51,   67,
       49,   68,   50,   70,  153,    4,    6,   52,  153,  151,

      152,  152,  152,  152,   28,   22,   26,   57,   63,   61,
       64,   58,  108,  149,  108,  149,  108,  149,  108,  149,
        2,   54,  108,  149,  108,  149,  108,  149,  108,  149,
      108,  149,  108,  149,  108,  149,  108,  149,  108,  149,
      108,  149,  108,  149,  108,  118,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  126,  149,  108,  149,  108,  149,  108,  149,
      108,  149,  108,  149,  108,  149,  108,  149,  108,  149,
      108,  149,  108,  149,  108,  149,  108,  149,   56,   66,
       33,  153,    6,  151,  152,  151,  152,  154,  152,  152,

      152,  150,   59,   60,  108,  149,  108,  149,  158,  156,
      108,  149,  108,  149,  108,  149,  108,  149,  108,  149,
      108,  149,  108,  149,  108,  149,  108,  149,  108,  149,
      108,  149,  108,  149,  108,  149,  108,  149,  108,  149,
      108,  149,  108,  109,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  124,  149,  108,  149,  108,  149,  108,  128,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,

      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  153,  151,  152,  151,  152,
      151,  152,  154,  152,  150,  150,  108,  149,  108,  149,
      108,  149,  104,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  110,  149,  108,  111,  149,  108,
      149,  108,  113,  149,  108,  114,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  120,  149,  108,  121,

      149,  108,  149,  108,  149,  108,  149,  108,  125,  149,
      108,  149,  108,  133,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  106,  108,  149,  108,  149,  108,  149,
      108,  149,  108,  146,  149,  108,  149,  108,  149,   18,
       13,  151,  152,  150,  150,  150,  105,  108,  149,  108,
      149,  108,  149,   94,  108,  149,  108,  149,  108,  149,
      108,  149,   74,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,

      149,  108,  149,  100,  108,  149,  108,  112,  149,  108,
      115,  149,  108,  149,  108,  149,  108,  149,  108,  149,
      107,  108,  149,  108,  123,  149,  108,  149,  108,  149,
      108,  149,  108,  149,  108,  137,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      144,  149,  108,  149,  108,  149,  108,  148,  149,   15,
      150,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,

      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      119,  149,  108,  122,  149,  108,  127,  149,  108,  149,
      108,  149,  108,  136,  149,  108,  138,  149,  108,  139,
      149,  108,  140,  149,  108,  141,  149,  108,  142,  149,
      108,  149,  108,  149,  108,  149,   14,   16,    5,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,   75,  108,  149,  108,  149,   96,  108,  149,   78,
      108,  149,  108,  149,  108,  149,  108,  149,  108,  149,
      101,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,

      117,  149,  108,  149,  108,  149,  108,  143,  149,  108,
      149,  108,  149,   12,  108,  149,  108,  149,   83,  108,
      149,  108,  149,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,   81,  108,  149,  108,  132,  149,  108,
      149,  108,  149,   87,  108,  149,  108,  149,   91,  108,
      149,  108,  149,  108,  149,  108,  116,  149,  108,  134,
      149,  108,  135,  149,  108,  145,  149,  108,  147,  149,
        8,   11,   19,   17,  108,  149,  108,  149,   86,  108,
      149,  108,  149,   84,  108,  149,  108,  149,  108,  149,
      108,  149,  108,  149,  108,  149,   82,  108,  149,  108,

      149,  108,  149,   99,  108,  149,  108,  131,  149,  108,
      149,    7,    8,  108,  149,  108,  149,  108,  149,  108,
      149,  108,  149,  108,  149,   80,  108,  149,  108,  130,
      149,   89,  108,  149,   88,  108,  149,  108,  149,   92,
      108,  149,  108,  149,  108,  149,  108,  149,   77,  108,
      149,  108,  149,  108,  149,  108,  129,  149,  108,  149,
      108,  149,  108,  149,  108,  149,  108,  149,  108,  149,
       90,  108,  149,   93,  108,  149,  108,  149,  108,  149,
      108,  149,   76,  108,  149,   98,   79,  108,  149,  108,
      149,  108,  149,  108,  149,   71,  108,  149,  108,  149,

      108,  149,  108,  149,  108,  149,  108,  149,   72,  102,
      108,  149,  108,  149,   85,  108,  149,  103,  108,  149,
       73,    9,    9,   12,   10,   10,   11,   97,   95
    } ;

static yyconst flex_int16_t yy_accept[702] =
    {   0,
        1,    1,    1,    2,    4,    7,    9,   12,   14,   17,
       20,   23,   25,   28,   31,   34,   37,   40,   43,   46,
       49,   52,   55,   58,   61,   64,   67,   70,   73,   77,
       81,   85,   89,   93,   96,   98,  101,  104,  108,  112,
      116,  120,  124,  128,  132,  136,  140,  144,  148,  152,
      156,  160,  164,  168,  171,  174,  177,  180,  181,  182,
      183,  183,  184,  184,  184,  184,  184,  184,  184,  184,
      185,  186,  187,  188,  188,  189,  189,  190,  191,  192,
      193,  194,  195,  195,  196,  197,  198,  199,  200,  202,
      203,  203,  204,  205,  205,  206,  207,  208,  209,  210,

      211,  212,  213,  215,  217,  219,  219,  219,  221,  222,
      223,  225,  227,  229,  231,  233,  235,  237,  239,  241,
      243,  245,  248,  250,  252,  254,  256,  258,  260,  262,
      265,  267,  269,  271,  273,  275,  277,  279,  281,  283,
      285,  287,  289,  290,  291,  291,  291,  291,  291,  291,
      291,  291,  292,  292,  293,  293,  293,  294,  296,  298,
      298,  299,  300,  301,  302,  303,  304,  305,  307,  309,
      309,  310,  310,  310,  311,  311,  313,  315,  317,  319,
      321,  323,  325,  327,  329,  331,  333,  335,  337,  339,
      341,  343,  346,  348,  350,  352,  354,  356,  358,  360,

      362,  364,  366,  368,  370,  372,  375,  377,  379,  382,
      384,  386,  388,  390,  392,  394,  396,  398,  400,  402,
      404,  406,  408,  410,  412,  414,  416,  416,  416,  416,
      416,  416,  416,  416,  416,  416,  416,  416,  417,  417,
      419,  421,  423,  424,  425,  426,  427,  429,  431,  433,
      436,  438,  440,  442,  444,  446,  448,  450,  452,  454,
      456,  458,  460,  462,  464,  466,  468,  470,  472,  474,
      477,  480,  482,  485,  488,  490,  492,  494,  496,  499,
      502,  504,  506,  508,  511,  513,  516,  518,  520,  522,
      524,  526,  528,  530,  532,  534,  537,  539,  541,  543,

      546,  548,  550,  550,  551,  551,  551,  551,  551,  551,
      552,  552,  552,  552,  552,  552,  554,  555,  556,  557,
      560,  562,  564,  567,  569,  571,  573,  576,  578,  580,
      582,  584,  586,  588,  590,  592,  594,  596,  598,  600,
      602,  604,  607,  610,  613,  615,  617,  619,  621,  624,
      627,  629,  631,  633,  635,  638,  640,  642,  644,  646,
      648,  650,  653,  655,  657,  660,  660,  660,  660,  661,
      661,  661,  661,  661,  661,  661,  661,  662,  664,  666,
      668,  670,  672,  674,  674,  676,  678,  680,  682,  684,
      686,  688,  690,  692,  694,  696,  698,  700,  702,  704,

      706,  708,  710,  713,  716,  719,  721,  723,  726,  729,
      732,  735,  738,  741,  743,  745,  747,  747,  747,  748,
      748,  749,  749,  749,  749,  749,  749,  750,  752,  754,
      756,  758,  760,  762,  762,  765,  767,  770,  773,  775,
      777,  779,  781,  784,  786,  788,  790,  792,  794,  796,
      798,  800,  803,  805,  807,  810,  812,  814,  814,  814,
      814,  814,  815,  815,  815,  815,  815,  815,  817,  819,
      822,  824,  826,  828,  828,  828,  830,  832,  834,  837,
      840,  842,  844,  847,  849,  852,  854,  856,  859,  862,
      865,  865,  868,  871,  872,  872,  872,  872,  872,  872,

      873,  873,  873,  874,  874,  875,  877,  879,  882,  884,
      887,  887,  887,  887,  889,  891,  893,  895,  897,  900,
      902,  904,  907,  910,  912,  912,  913,  914,  914,  914,
      914,  914,  916,  918,  920,  920,  920,  920,  922,  924,
      926,  929,  932,  935,  938,  940,  943,  943,  943,  943,
      943,  943,  945,  947,  949,  949,  949,  949,  952,  952,
      952,  954,  956,  959,  961,  961,  961,  961,  961,  961,
      963,  965,  967,  967,  967,  967,  969,  969,  969,  969,
      971,  974,  977,  977,  977,  977,  977,  977,  979,  981,
      983,  983,  983,  983,  986,  987,  987,  990,  990,  990,

      990,  990,  990,  992,  994,  996,  997,  997,  997,  997,
      997,  997,  997,  997,  997,  999, 1001, 1003, 1003, 1003,
     1003, 1003, 1003, 1003, 1003, 1003, 1005, 1007, 1009, 1009,
     1010, 1010, 1010, 1010, 1010, 1010, 1010, 1013, 1015, 1018,
     1018, 1018, 1018, 1018, 1018, 1018, 1018, 1021, 1021, 1021,
     1021, 1021, 1021, 1021, 1021, 1021, 1021, 1021, 1021, 1021,
     1021, 1021, 1022, 1022, 1022, 1022, 1022, 1022, 1022, 1022,
     1022, 1022, 1022, 1023, 1023, 1023, 1025, 1025, 1025, 1025,
     1025, 1025, 1025, 1026, 1026, 1026, 1028, 1028, 1028, 1028,
     1029, 1029, 1029, 1029, 1029, 1029, 1029, 1029, 1029, 1030,

     1030
    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    1,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       23,   24,   23,   25,   23,   26,   27,   28,   29,   30,
       31,   32,   33,    1,   34,   35,   36,   37,   38,   39,
       40,   41,   42,   41,   41,   43,   41,   44,   45,   41,
       41,   46,   47,   48,   49,   41,   41,   50,   41,   41,
       51,   52,   53,   54,   55,    1,   56,   57,   58,   59,

       60,   61,   62,   63,   64,   65,   66,   67,   68,   69,
       70,   71,   65,   72,   73,   74,   75,   76,   77,   78,
       79,   80,   81,   82,   83,   84,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[85] =
    {   0,
        1,    2,    3,    1,    2,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    5,    1,    1,    1,    6,
        6,    6,    6,    6,    6,    6,    6,    1,    1,    1,
        5,    1,    1,    7,    7,    7,    7,    7,    7,    8,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
        1,    1,    1,    1,    8,    9,    9,    9,    9,    9,
        9,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
        1,    1,    1,    1
    } ;

static yyconst flex_uint16_t yy_base[728] =
    {   0,
        0,    0, 1197, 1198,   83,    0, 1165,   79,   84,   59,
       82,   82, 1198, 1198, 1164,   79, 1198,   80,   78,   95,
      138,  199, 1162, 1198,   97, 1162,   76, 1198,    0, 1158,
     1136,  108, 1144, 1198, 1186, 1198, 1157,   85,   43,   51,
       76,   75,   55,   80, 1117,   69, 1116, 1125,  103,   70,
     1115, 1113, 1119, 1198,   86, 1198, 1198,  167,    0, 1198,
      130, 1198, 1178,  169, 1120,   85, 1118, 1114, 1105, 1198,
     1198, 1198, 1198,  159, 1198, 1173, 1198, 1198, 1198, 1198,
     1198, 1198, 1157,  255,  173,    0, 1198,    0,  165,    0,
      229,  161,  130,    0, 1198, 1198, 1198, 1143, 1198, 1198,

     1198, 1142,    0, 1129, 1131,  134,  189, 1121, 1198, 1198,
     1099,  104,  227, 1100, 1093, 1096, 1105, 1091, 1107, 1093,
     1100, 1085, 1086, 1083, 1083, 1089, 1085, 1082, 1079,    0,
      132, 1083,  156, 1081,  121,  175, 1086, 1074, 1077,  194,
      145, 1083, 1198, 1198,  285, 1085,  196, 1086,  202, 1075,
     1087, 1198,  303, 1198, 1112,    0,    0,  190,  195,  311,
      319,  214, 1198,  221,  304, 1198, 1198, 1094,  185,  150,
     1198, 1137,  261, 1198, 1136, 1100, 1067,  201, 1069,  111,
      225, 1075, 1056, 1064, 1062, 1071,  171, 1051, 1065, 1058,
     1102,    0, 1056, 1058, 1068, 1063, 1050,  275, 1065, 1063,

     1059, 1050, 1057, 1043, 1059,    0, 1044, 1049,    0, 1050,
     1047, 1036, 1034, 1036, 1038, 1046, 1031, 1029, 1029, 1042,
     1041, 1030, 1035, 1039, 1041, 1029, 1092, 1030, 1032, 1032,
     1027, 1087, 1029, 1029, 1027, 1024,  343,  367, 1053,  301,
     1198,  225, 1198, 1198,  308,  254, 1046, 1039, 1040,    0,
     1014, 1011, 1019, 1011, 1009, 1002, 1015, 1005, 1015,  998,
      285, 1002,  997, 1007, 1009,  996,  997,  998, 1040,    0,
        0,  997,    0,    0,  988,  997,  985,  992,    0,    0,
      986,  997,  982,    0,  986,    0,  981,  981,  980,  977,
      990,  979,  984,  989,  988,    0,  986,  975,  981,    0,

      968,  981, 1037, 1198,  970, 1033, 1034,  975, 1032, 1198,
      973,  973, 1027,  963,  393, 1198,  306, 1198,  311,    0,
      982,  985,    0,  953,  953,  305,  380,  954,  967,  951,
      956,  962,  957,  352,  951,  945,  949,  959,  956,  941,
      958,    0,    0,    0,  944,  945,  951,  941,    0,    0,
      949,  934,  943,  937,    0,  946,  943,  945,  928,  938,
      940,    0,  930,  934,    0,  937,  993,  992, 1198,  991,
      312,  932,  391,  936,  977,  971, 1198,  964,  940,  920,
      911,  910,  927,  395,  928,  918,  914,  906,  906,  909,
      908,  954,  951,  899,  901,  912,  915,  900,  948,  894,

      892,  892,    0,    0,    0,  905,  906,    0,    0,    0,
        0,    0,    0,  902,  902,  894,  955,  956, 1198,  955,
     1198,  399,  400,  417,  416,  952, 1198,  932,  930,  887,
      881,  883,  884,  880,  421,  892,    0,    0,  877,  874,
      886,  919,    0,  877,  879,  883,  874,  879,  917,  874,
      877,    0,  864,  861,  929,  874,  872,    0,  876,  927,
      427, 1198,  353,  422,  442,  926,  925,  872,  902,    0,
      856,  851,  863,  855,  444,  846,  860,  855,  863,  862,
      849,  857,  859,  846,    0,  886,  844,    0,    0,    0,
      852,    0,    0,  897,  868,  369,  852,  903,  448, 1198,

      417,  902, 1198,  901, 1198,  867,  847,    0,  830,    0,
      844,  844,  828,  823,  838,  825,  839,  819,    0,  818,
      836,    0,  835,  829,  825, 1198,  875,  844,  428,  845,
      393,  839,  847,  822,  807,  804,  812,  818,  454,  808,
        0,    0,  821,    0,  801,  819,  817,  817,  449,  829,
      454,  826,  824,  810,  803,  796,  809,  809,  456,  804,
      807,  806,    0,  805,  787,  811,  459,  802,  457,  809,
      811,  790,  786,  785,  777,  795,    0,  836,  450,  793,
        0,    0,  842,  810,  462,  798,  461,  796,  796,  781,
      781,  784,  775,    0, 1198,   82,    0,  783,  803,  466,

      800,  471,  801,  786,  769, 1198,  758,  764,  454,  775,
      785,  470,  794,  475,  783,  792,  765,  760,  763,  462,
      749,  777,  473,  776,  477,  771,  774,  758,  749, 1198,
      466,  741,  776,  478,  769,  481,    0,  764,    0,  751,
      472,  754,  763,  483,  770,  480,    0,  752,  474,  732,
      750,  485,  741,  486,  687,  477,  677,  685,  488,  684,
      489, 1198,  480,  680,  528,  533,  682,  491,  489,  675,
      625,  624, 1198,  601,  591, 1198,  547,  551,  546,  499,
      548,  544, 1198,  542,  539, 1198,  528,  521,  454,  510,
      446,  455,  441,  437,  450,  421,  371,  316, 1198, 1198,

      556,  566,  576,  581,  591,  596,  605,  615,  624,  634,
      644,  654,  664,  674,  684,  688,  698,  708,  718,  725,
      734,  744,  754,  764,  774,  784,  794
    } ;

static yyconst flex_int16_t yy_def[728] =
    {   0,
      700,    1,  700,  700,  700,  701,  700,  702,  700,  700,
      700,  703,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  704,  704,
      704,  704,  704,  700,  700,  700,  700,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  700,  700,  700,  700,  700,  701,  700,
      702,  700,  702,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  703,  700,  703,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  705,  700,   84,   21,   22,
      700,  700,  700,  706,  700,  700,  700,  700,  700,  700,

      700,  700,  704,  704,  704,  707,  708,  704,  700,  700,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  709,  705,  700,  700,  700,
      700,  700,  700,  700,  706,  700,  700,  704,  704,  707,
      700,  707,  708,  700,  708,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,

      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  710,  700,  700,  700,
      700,  711,  700,  700,  700,  700,  700,  700,  709,  700,
      700,  700,  700,  700,  700,  700,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,

      704,  704,  710,  700,  700,  700,  712,  700,  711,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  700,  713,  712,  700,  714,
      700,  700,  700,  700,  700,  700,  700,  704,  704,  704,
      704,  704,  704,  700,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,

      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  700,  713,  700,  714,
      700,  700,  715,  700,  700,  700,  700,  704,  704,  704,
      704,  704,  704,  700,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  716,  700,  715,
      715,  700,  715,  700,  717,  718,  719,  704,  704,  704,
      704,  704,  704,  700,  700,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      700,  704,  704,  720,  700,  715,  700,  717,  717,  700,

      717,  718,  700,  719,  700,  704,  704,  704,  704,  704,
      700,  700,  700,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  700,  700,  720,  700,  715,  700,
      717,  704,  704,  704,  700,  700,  700,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  700,  700,  715,  700,
      717,  704,  704,  704,  700,  700,  700,  704,  700,  721,
      704,  704,  704,  704,  700,  700,  715,  700,  717,  704,
      704,  704,  700,  700,  700,  704,  721,  721,  721,  704,
      704,  704,  700,  700,  715,  700,  717,  704,  704,  704,
      700,  700,  700,  704,  700,  721,  704,  700,  700,  715,

      700,  717,  704,  704,  704,  700,  700,  700,  721,  700,
      700,  715,  700,  717,  704,  704,  704,  700,  700,  721,
      700,  700,  715,  700,  717,  704,  704,  704,  700,  700,
      721,  700,  700,  715,  700,  717,  704,  704,  704,  700,
      721,  700,  700,  715,  700,  717,  704,  700,  721,  700,
      700,  715,  700,  717,  700,  721,  700,  700,  715,  700,
      717,  700,  721,  700,  722,  723,  700,  717,  721,  700,
      722,  722,  700,  723,  723,  700,  724,  725,  726,  700,
      724,  724,  700,  725,  725,  700,  726,  726,  700,  726,
      700,  700,  700,  700,  700,  700,  727,  727,  700,    0,

      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700
    } ;

static yyconst flex_uint16_t yy_nxt[1283] =
    {   0,
        4,    5,    6,    5,    5,    7,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,   22,   22,   22,   22,   22,   22,   23,   24,   25,
       26,   27,   28,   29,   29,   29,   29,   29,   30,   31,
       29,   29,   32,   29,   29,   29,   29,   33,   29,   29,
       34,   35,   36,   37,   38,   39,   40,   41,   42,   43,
       44,   45,   29,   46,   29,   29,   47,   29,   29,   29,
       29,   48,   49,   50,   51,   52,   53,   29,   29,   29,
       54,   55,   56,   57,   58,   62,   58,   58,   64,   70,
       71,   72,   75,   78,  595,   83,   80,   84,   84,   84,

       84,   84,   84,   84,   84,   96,  101,  102,   85,   79,
       81,   82,   73,   86,  106,  114,  143,  115,  107,  111,
      116,  123,  117,  124,   97,   87,   98,   99,  112,  130,
       63,  118,  125,   76,  121,  126,   62,  131,  119,  113,
      171,  138,   65,   66,  122,  120,  127,   67,  139,  128,
       68,  147,  609,  148,   69,   88,  171,   89,   89,   89,
       89,   89,   89,   90,   90,  134,  135,  144,   58,   75,
       58,   58,  164,  178,  155,   91,  136,  155,  179,  137,
       92,   63,  215,  255,  256,  172,   93,   94,  145,  145,
      145,  145,  145,  145,  145,  145,  164,   91,  208,  174,

      216,  172,  156,  162,   92,  209,  232,  158,  224,  163,
       76,  225,   93,  159,  700,   94,   88,  211,   90,   90,
       90,   90,   90,   90,   90,   90,  248,  162,  212,  213,
      217,  158,  240,  249,  264,  163,   91,  242,  241,  159,
      175,   92,  700,  160,  265,  160,  218,   93,  161,  161,
      161,  161,  161,  161,  161,  161,  240,  222,   91,  229,
      233,  242,  163,  244,  241,   92,  223,  316,  230,  252,
      234,  174,  253,   93,   84,   84,   84,   84,   84,   84,
       84,   84,  180,  257,  181,  182,  183,  244,  163,  227,
      184,  316,  153,  154,  258,  185,  319,  154,  186,  187,

      188,  189,  190,  191,  145,  145,  145,  145,  145,  145,
      145,  145,  175,  422,  153,  154,  423,  237,  699,  237,
      319,  154,  238,  238,  238,  238,  238,  238,  238,  238,
      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  245,  275,  276,  241,
      317,  333,  246,  377,  318,  462,  318,  243,  334,  382,
      383,  243,  238,  238,  238,  238,  238,  238,  238,  238,
      245,  462,  392,  699,  317,  241,  393,  377,  246,  243,
      318,  384,  318,  384,  384,  243,  238,  238,  238,  238,
      238,  238,  238,  238,  375,  500,  384,  375,  384,  384,

      422,  461,  462,  422,  461,  154,  376,  496,  529,  154,
      425,  425,  425,  425,  425,  425,  425,  425,  464,  500,
      466,  465,  475,  464,  475,  475,  464,  154,  461,  462,
      462,  461,  551,  154,  385,  425,  425,  425,  425,  425,
      425,  425,  425,  499,  500,  475,  499,  475,  475,  499,
      500,  462,  499,  459,  463,  559,  500,  559,  559,  500,
      559,  462,  595,  500,  462,  560,  595,  577,  462,  549,
      434,  531,  462,  500,  595,  462,  497,  500,  595,  500,
      462,  463,  500,  500,  595,  462,  595,  462,  500,  595,
      462,  500,  595,  500,  697,  569,  501,  600,  512,  612,

      679,  595,  501,  567,  696,  585,  614,  602,  625,  596,
      695,  587,  694,  623,  693,  644,  634,  654,  692,  513,
      636,  631,  690,  641,  646,  620,  691,  649,  652,  672,
      673,  661,  672,  690,  675,  676,  663,  675,  669,  659,
      688,  686,  666,  668,  686,  678,  683,  656,  682,  683,
      683,  682,  685,  686,  689,  685,   59,   59,  688,   59,
       59,   59,   59,   59,   59,   59,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   74,   74,   74,   74,
       74,   74,   74,   74,   74,   74,  103,  103,  103,  103,
      103,  157,  157,  676,  157,  157,  157,  157,  157,  157,

      157,  165,  165,  676,  165,  170,  170,  170,  170,  170,
      170,  170,  170,  170,  170,  173,  173,  173,  173,  173,
      173,  173,  173,  173,  173,  239,  673,  673,  239,  239,
      239,  239,  239,  239,  303,  303,  303,  303,  303,  303,
      303,  303,  303,  303,  309,  309,  309,  309,  309,  309,
      309,  309,  309,  309,  368,  368,  368,  368,  368,  368,
      368,  368,  368,  368,  418,  418,  418,  418,  418,  418,
      418,  418,  418,  418,  420,  420,  420,  420,  420,  420,
      420,  420,  420,  420,  460,  460,  460,  460,  460,  460,
      460,  460,  460,  460,  494,  494,  494,  494,  498,  498,

      498,  498,  498,  498,  498,  498,  498,  498,  502,  502,
      502,  502,  502,  502,  502,  502,  502,  502,  504,  504,
      504,  504,  504,  504,  504,  504,  504,  504,  527,  680,
      527,  527,  527,  527,  527,  578,  677,  670,  667,  665,
      664,  662,  578,  578,  671,  671,  671,  671,  671,  671,
      671,  671,  671,  671,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  681,  681,  681,  681,  681,  681,
      681,  681,  681,  681,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  687,  687,  660,  687,  687,  687,
      687,  687,  687,  687,  698,  698,  698,  698,  698,  698,

      698,  698,  698,  698,  658,  657,  655,  653,  651,  650,
      648,  647,  645,  643,  642,  640,  639,  638,  637,  635,
      633,  632,  630,  629,  628,  627,  626,  624,  622,  621,
      619,  618,  617,  616,  615,  613,  611,  610,  608,  607,
      606,  605,  604,  603,  601,  599,  598,  597,  595,  594,
      593,  592,  591,  590,  589,  588,  586,  584,  583,  582,
      581,  580,  579,  576,  575,  574,  573,  572,  571,  570,
      568,  566,  565,  564,  563,  562,  561,  558,  557,  556,
      555,  554,  553,  552,  550,  548,  526,  547,  546,  545,
      544,  543,  542,  541,  540,  539,  538,  537,  536,  535,

      534,  533,  532,  505,  503,  500,  530,  528,  526,  525,
      524,  523,  522,  521,  520,  519,  518,  517,  516,  515,
      514,  511,  510,  509,  508,  507,  506,  505,  503,  462,
      495,  493,  492,  491,  490,  489,  488,  487,  486,  485,
      484,  483,  482,  481,  480,  479,  478,  477,  476,  474,
      473,  472,  471,  470,  469,  468,  467,  421,  419,  458,
      457,  456,  455,  454,  453,  452,  451,  450,  449,  448,
      447,  446,  445,  444,  443,  442,  441,  440,  439,  438,
      437,  436,  435,  433,  432,  431,  430,  429,  428,  427,
      376,  426,  424,  421,  369,  419,  417,  416,  415,  414,

      413,  412,  411,  410,  409,  408,  407,  406,  405,  404,
      403,  402,  401,  400,  399,  398,  397,  396,  395,  394,
      391,  390,  389,  388,  387,  386,  381,  380,  379,  378,
      374,  373,  372,  371,  310,  370,  369,  367,  366,  304,
      365,  364,  363,  362,  361,  360,  359,  358,  357,  356,
      355,  354,  353,  352,  351,  350,  349,  348,  347,  346,
      345,  344,  343,  342,  341,  340,  339,  338,  337,  336,
      335,  332,  331,  330,  329,  328,  327,  326,  325,  324,
      323,  322,  321,  320,  315,  314,  313,  312,  311,  310,
      308,  307,  306,  305,  304,  302,  301,  300,  299,  298,

      297,  296,  295,  294,  293,  292,  291,  290,  289,  288,
      287,  286,  285,  284,  283,  282,  281,  280,  279,  278,
      277,  274,  273,  272,  271,  270,  269,  268,  267,  266,
      263,  262,  261,  260,  259,  254,  251,  250,  700,  700,
      247,  156,  236,  235,  231,  228,  226,  221,  220,  219,
      214,  210,  207,  206,  205,  204,  203,  202,  201,  200,
      199,  198,  197,  196,  195,  194,  193,  192,  177,  176,
      169,  168,  167,  166,  152,  700,  151,  150,  149,  146,
      700,  142,  141,  140,  133,  132,  129,  110,  109,  108,
      105,  104,  100,   95,   77,   60,  700,    3,  700,  700,

      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700
    } ;

static yyconst flex_int16_t yy_chk[1283] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    5,    8,    5,    5,    9,   10,
       10,   11,   12,   16,  596,   19,   18,   19,   19,   19,

       19,   19,   19,   19,   19,   25,   27,   27,   20,   16,
       18,   18,   11,   20,   32,   39,   55,   39,   32,   38,
       40,   43,   40,   43,   25,   20,   25,   25,   38,   46,
        8,   41,   43,   12,   42,   44,   61,   46,   41,   38,
      106,   50,    9,    9,   42,   41,   44,    9,   50,   44,
        9,   66,  596,   66,    9,   21,  170,   21,   21,   21,
       21,   21,   21,   21,   21,   49,   49,   55,   58,   74,
       58,   58,   93,  112,   85,   21,   49,   85,  112,   49,
       21,   61,  135,  180,  180,  106,   21,   21,   64,   64,
       64,   64,   64,   64,   64,   64,   93,   21,  131,  107,

      135,  170,   85,   92,   21,  131,  149,   89,  141,   92,
       74,  141,   21,   89,   89,   21,   22,  133,   22,   22,
       22,   22,   22,   22,   22,   22,  169,   92,  133,  133,
      136,   89,  158,  169,  187,   92,   22,  159,  158,   89,
      107,   22,   89,   91,  187,   91,  136,   22,   91,   91,
       91,   91,   91,   91,   91,   91,  158,  140,   22,  147,
      149,  159,  162,  164,  158,   22,  140,  242,  147,  178,
      149,  173,  178,   22,   84,   84,   84,   84,   84,   84,
       84,   84,  113,  181,  113,  113,  113,  164,  162,  145,
      113,  242,   84,   84,  181,  113,  246,   84,  113,  113,

      113,  113,  113,  113,  145,  145,  145,  145,  145,  145,
      145,  145,  173,  371,   84,   84,  371,  153,  698,  153,
      246,   84,  153,  153,  153,  153,  153,  153,  153,  153,
      160,  160,  160,  160,  160,  160,  160,  160,  161,  161,
      161,  161,  161,  161,  161,  161,  165,  198,  198,  240,
      245,  261,  165,  319,  317,  463,  245,  161,  261,  326,
      326,  161,  237,  237,  237,  237,  237,  237,  237,  237,
      165,  496,  334,  697,  245,  240,  334,  319,  165,  161,
      317,  327,  245,  327,  327,  161,  238,  238,  238,  238,
      238,  238,  238,  238,  315,  531,  384,  315,  384,  384,

      422,  423,  423,  422,  423,  238,  315,  463,  496,  238,
      373,  373,  373,  373,  373,  373,  373,  373,  424,  501,
      425,  424,  435,  464,  435,  435,  464,  238,  461,  461,
      529,  461,  531,  238,  327,  425,  425,  425,  425,  425,
      425,  425,  425,  465,  465,  475,  465,  475,  475,  499,
      499,  549,  499,  422,  423,  539,  551,  559,  539,  569,
      559,  567,  579,  587,  585,  539,  609,  559,  600,  529,
      384,  501,  612,  602,  620,  623,  464,  614,  631,  625,
      634,  461,  646,  636,  641,  644,  649,  652,  654,  656,
      659,  661,  663,  668,  696,  551,  465,  585,  475,  600,

      669,  669,  499,  549,  695,  567,  602,  587,  614,  579,
      694,  569,  693,  612,  692,  634,  623,  646,  691,  475,
      625,  620,  690,  631,  636,  609,  689,  641,  644,  665,
      665,  654,  665,  688,  666,  666,  656,  666,  663,  652,
      687,  685,  659,  661,  684,  668,  682,  649,  677,  677,
      681,  677,  678,  678,  680,  678,  701,  701,  679,  701,
      701,  701,  701,  701,  701,  701,  702,  702,  702,  702,
      702,  702,  702,  702,  702,  702,  703,  703,  703,  703,
      703,  703,  703,  703,  703,  703,  704,  704,  704,  704,
      704,  705,  705,  675,  705,  705,  705,  705,  705,  705,

      705,  706,  706,  674,  706,  707,  707,  707,  707,  707,
      707,  707,  707,  707,  707,  708,  708,  708,  708,  708,
      708,  708,  708,  708,  708,  709,  672,  671,  709,  709,
      709,  709,  709,  709,  710,  710,  710,  710,  710,  710,
      710,  710,  710,  710,  711,  711,  711,  711,  711,  711,
      711,  711,  711,  711,  712,  712,  712,  712,  712,  712,
      712,  712,  712,  712,  713,  713,  713,  713,  713,  713,
      713,  713,  713,  713,  714,  714,  714,  714,  714,  714,
      714,  714,  714,  714,  715,  715,  715,  715,  715,  715,
      715,  715,  715,  715,  716,  716,  716,  716,  717,  717,

      717,  717,  717,  717,  717,  717,  717,  717,  718,  718,
      718,  718,  718,  718,  718,  718,  718,  718,  719,  719,
      719,  719,  719,  719,  719,  719,  719,  719,  720,  670,
      720,  720,  720,  720,  720,  721,  667,  664,  660,  658,
      657,  655,  721,  721,  722,  722,  722,  722,  722,  722,
      722,  722,  722,  722,  723,  723,  723,  723,  723,  723,
      723,  723,  723,  723,  724,  724,  724,  724,  724,  724,
      724,  724,  724,  724,  725,  725,  725,  725,  725,  725,
      725,  725,  725,  725,  726,  726,  653,  726,  726,  726,
      726,  726,  726,  726,  727,  727,  727,  727,  727,  727,

      727,  727,  727,  727,  651,  650,  648,  645,  643,  642,
      640,  638,  635,  633,  632,  629,  628,  627,  626,  624,
      622,  621,  619,  618,  617,  616,  615,  613,  611,  610,
      608,  607,  605,  604,  603,  601,  599,  598,  593,  592,
      591,  590,  589,  588,  586,  584,  583,  580,  578,  576,
      575,  574,  573,  572,  571,  570,  568,  566,  565,  564,
      562,  561,  560,  558,  557,  556,  555,  554,  553,  552,
      550,  548,  547,  546,  545,  543,  540,  538,  537,  536,
      535,  534,  533,  532,  530,  528,  527,  525,  524,  523,
      521,  520,  518,  517,  516,  515,  514,  513,  512,  511,

      509,  507,  506,  504,  502,  498,  497,  495,  494,  491,
      487,  486,  484,  483,  482,  481,  480,  479,  478,  477,
      476,  474,  473,  472,  471,  469,  468,  467,  466,  460,
      459,  457,  456,  455,  454,  453,  451,  450,  449,  448,
      447,  446,  445,  444,  442,  441,  440,  439,  436,  434,
      433,  432,  431,  430,  429,  428,  426,  420,  418,  417,
      416,  415,  414,  407,  406,  402,  401,  400,  399,  398,
      397,  396,  395,  394,  393,  392,  391,  390,  389,  388,
      387,  386,  385,  383,  382,  381,  380,  379,  378,  376,
      375,  374,  372,  370,  368,  367,  366,  364,  363,  361,

      360,  359,  358,  357,  356,  354,  353,  352,  351,  348,
      347,  346,  345,  341,  340,  339,  338,  337,  336,  335,
      333,  332,  331,  330,  329,  328,  325,  324,  322,  321,
      314,  313,  312,  311,  309,  308,  307,  306,  305,  303,
      302,  301,  299,  298,  297,  295,  294,  293,  292,  291,
      290,  289,  288,  287,  285,  283,  282,  281,  278,  277,
      276,  275,  272,  269,  268,  267,  266,  265,  264,  263,
      262,  260,  259,  258,  257,  256,  255,  254,  253,  252,
      251,  249,  248,  247,  239,  236,  235,  234,  233,  232,
      231,  230,  229,  228,  227,  226,  225,  224,  223,  222,

      221,  220,  219,  218,  217,  216,  215,  214,  213,  212,
      211,  210,  208,  207,  205,  204,  203,  202,  201,  200,
      199,  197,  196,  195,  194,  193,  191,  190,  189,  188,
      186,  185,  184,  183,  182,  179,  177,  176,  175,  172,
      168,  155,  151,  150,  148,  146,  142,  139,  138,  137,
      134,  132,  129,  128,  127,  126,  125,  124,  123,  122,
      121,  120,  119,  118,  117,  116,  115,  114,  111,  108,
      105,  104,  102,   98,   83,   76,   69,   68,   67,   65,
       63,   53,   52,   51,   48,   47,   45,   37,   35,   33,
       31,   30,   26,   23,   15,    7,    3,  700,  700,  700,

      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700
    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "giscanner/scannerlexer.l"
/* -*- Mode: C -*-
 * GObject introspection: C lexer
 *
 * Copyright (c) 1997 Sandro Sigala  <ssigala@globalnet.it>
 * Copyright (c) 2007-2008 Jürg Billeter  <j@bitron.ch>
 * Copyright (c) 2010 Andreas Rottmann <a.rottmann@gmx.at>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#line 32 "giscanner/scannerlexer.l"
#include <ctype.h>
#include <stdio.h>
#include <string.h>
#ifndef _WIN32
#include <limits.h>
#endif

#include <glib.h>
#include "sourcescanner.h"
#include "scannerparser.h"

#ifdef USE_WINDOWS
#include <windows.h>
#endif

int lineno;
char linebuf[2000];

#undef YY_BUF_SIZE
#define YY_BUF_SIZE 1048576

extern int yylex (GISourceScanner *scanner);
#define YY_DECL int yylex (GISourceScanner *scanner)
static int yywrap (void);
static void parse_comment (GISourceScanner *scanner);
static void parse_trigraph (GISourceScanner *scanner);
static void process_linemarks (GISourceScanner *scanner, gboolean has_line);
static int check_identifier (GISourceScanner *scanner, const char *);
static int parse_ignored_macro (void);
static void print_error (GISourceScanner *scanner);

#if (YY_FLEX_MAJOR_VERSION > 2) \
  || ((YY_FLEX_MAJOR_VERSION == 2) && (YY_FLEX_MINOR_VERSION > 6)) \
  || ((YY_FLEX_MAJOR_VERSION == 2) && (YY_FLEX_MINOR_VERSION == 6) && (YY_FLEX_SUBMINOR_VERSION >= 1))
#define IS_EOF 0
#else
#define IS_EOF EOF
#endif

#line 1163 "scannerlexer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * _in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * _out_str  );

			int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	{
#line 82 "giscanner/scannerlexer.l"


#line 1388 "scannerlexer.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 701 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1198 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 84 "giscanner/scannerlexer.l"
{ strncpy(linebuf, yytext+1, sizeof(linebuf)); /* save the next line */
						linebuf[sizeof(linebuf)-1]='\0';
						/* printf("%4d:%s\n",lineno,linebuf); */
						yyless(1);      /* give back all but the \n to rescan */
						++lineno;
					}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 90 "giscanner/scannerlexer.l"
{ ++lineno; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 92 "giscanner/scannerlexer.l"
{ /* Ignore whitespace. */ }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 94 "giscanner/scannerlexer.l"
{ parse_comment(scanner); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 95 "giscanner/scannerlexer.l"
{ parse_trigraph(scanner); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 96 "giscanner/scannerlexer.l"
{ /* Ignore C++ style comments. */ }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 98 "giscanner/scannerlexer.l"
{ yyless (yyleng - 1); return FUNCTION_MACRO; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 99 "giscanner/scannerlexer.l"
{ return OBJECT_MACRO; }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 100 "giscanner/scannerlexer.l"
{ ++lineno; return IFDEF_GI_SCANNER; }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 101 "giscanner/scannerlexer.l"
{ ++lineno; return IFNDEF_GI_SCANNER; }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 102 "giscanner/scannerlexer.l"
{ ++lineno; return IFNDEF_COND; }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 103 "giscanner/scannerlexer.l"
{ ++lineno; return IFDEF_COND; }
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 104 "giscanner/scannerlexer.l"
{ ++lineno; return IF_COND; }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 105 "giscanner/scannerlexer.l"
{ ++lineno; return ELIF_COND; }
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 106 "giscanner/scannerlexer.l"
{ ++lineno; return ELSE_COND; }
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 107 "giscanner/scannerlexer.l"
{ ++lineno; return ENDIF_COND; }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 108 "giscanner/scannerlexer.l"
{ ++lineno; /* Ignore pragma. */ }
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 110 "giscanner/scannerlexer.l"
{ ++lineno; process_linemarks(scanner, FALSE); }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 111 "giscanner/scannerlexer.l"
{ ++lineno; process_linemarks(scanner, TRUE); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 112 "giscanner/scannerlexer.l"
{ }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 113 "giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 114 "giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 115 "giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 116 "giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 117 "giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 118 "giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 119 "giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 120 "giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 121 "giscanner/scannerlexer.l"
{ return '('; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 122 "giscanner/scannerlexer.l"
{ return ')'; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 123 "giscanner/scannerlexer.l"
{ return ';'; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 124 "giscanner/scannerlexer.l"
{ return ':'; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 125 "giscanner/scannerlexer.l"
{ return ELLIPSIS; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 126 "giscanner/scannerlexer.l"
{ return '?'; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 127 "giscanner/scannerlexer.l"
{ return '.'; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 128 "giscanner/scannerlexer.l"
{ return '+'; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 129 "giscanner/scannerlexer.l"
{ return '-'; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 130 "giscanner/scannerlexer.l"
{ return '*'; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 131 "giscanner/scannerlexer.l"
{ return '/'; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 132 "giscanner/scannerlexer.l"
{ return '%'; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 133 "giscanner/scannerlexer.l"
{ return '^'; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 134 "giscanner/scannerlexer.l"
{ return '&'; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 135 "giscanner/scannerlexer.l"
{ return '|'; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 136 "giscanner/scannerlexer.l"
{ return '~'; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 137 "giscanner/scannerlexer.l"
{ return '!'; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 138 "giscanner/scannerlexer.l"
{ return '='; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 139 "giscanner/scannerlexer.l"
{ return '<'; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 140 "giscanner/scannerlexer.l"
{ return '>'; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 141 "giscanner/scannerlexer.l"
{ return ADDEQ; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 142 "giscanner/scannerlexer.l"
{ return SUBEQ; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 143 "giscanner/scannerlexer.l"
{ return MULEQ; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 144 "giscanner/scannerlexer.l"
{ return DIVEQ; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 145 "giscanner/scannerlexer.l"
{ return MODEQ; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 146 "giscanner/scannerlexer.l"
{ return XOREQ; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 147 "giscanner/scannerlexer.l"
{ return ANDEQ; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 148 "giscanner/scannerlexer.l"
{ return OREQ; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 149 "giscanner/scannerlexer.l"
{ return SL; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 150 "giscanner/scannerlexer.l"
{ return SR; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 151 "giscanner/scannerlexer.l"
{ return SLEQ; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 152 "giscanner/scannerlexer.l"
{ return SREQ; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 153 "giscanner/scannerlexer.l"
{ return EQ; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 154 "giscanner/scannerlexer.l"
{ return NOTEQ; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 155 "giscanner/scannerlexer.l"
{ return LTEQ; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 156 "giscanner/scannerlexer.l"
{ return GTEQ; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 157 "giscanner/scannerlexer.l"
{ return ANDAND; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 158 "giscanner/scannerlexer.l"
{ return OROR; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 159 "giscanner/scannerlexer.l"
{ return PLUSPLUS; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 160 "giscanner/scannerlexer.l"
{ return MINUSMINUS; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 161 "giscanner/scannerlexer.l"
{ return ','; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 162 "giscanner/scannerlexer.l"
{ return ARROW; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 164 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 165 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 166 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 167 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 168 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 169 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 170 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 171 "giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 172 "giscanner/scannerlexer.l"
{ return EXTENSION; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 173 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 174 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 175 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 176 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 177 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 178 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 179 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 180 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 181 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 182 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 183 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 184 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 185 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 186 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 187 "giscanner/scannerlexer.l"
{ return BOOL; }
	YY_BREAK
case 95:
/* rule 95 can match eol */
YY_RULE_SETUP
#line 188 "giscanner/scannerlexer.l"
{ ++lineno; /* Ignore */ }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 189 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 190 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 191 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 192 "giscanner/scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 193 "giscanner/scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 194 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 197 "giscanner/scannerlexer.l"
{ return INTL_CONST; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 198 "giscanner/scannerlexer.l"
{ return INTUL_CONST; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 200 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 201 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 202 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 203 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 205 "giscanner/scannerlexer.l"
{ if (scanner->macro_scan) return check_identifier(scanner, yytext); else REJECT; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 207 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 208 "giscanner/scannerlexer.l"
{ return AUTO; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 209 "giscanner/scannerlexer.l"
{ return BOOL; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 210 "giscanner/scannerlexer.l"
{ return BREAK; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 211 "giscanner/scannerlexer.l"
{ return CASE; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 212 "giscanner/scannerlexer.l"
{ return CHAR; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 213 "giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 214 "giscanner/scannerlexer.l"
{ return CONTINUE; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 215 "giscanner/scannerlexer.l"
{ return DEFAULT; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 216 "giscanner/scannerlexer.l"
{ return DO; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 217 "giscanner/scannerlexer.l"
{ return DOUBLE; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 218 "giscanner/scannerlexer.l"
{ return ELSE; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 219 "giscanner/scannerlexer.l"
{ return ENUM; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 220 "giscanner/scannerlexer.l"
{ return EXTERN; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 221 "giscanner/scannerlexer.l"
{ return FLOAT; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 222 "giscanner/scannerlexer.l"
{ return FOR; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 223 "giscanner/scannerlexer.l"
{ return GOTO; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 224 "giscanner/scannerlexer.l"
{ return IF; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 225 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 226 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 227 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 228 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 229 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 230 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 231 "giscanner/scannerlexer.l"
{ return LONG; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 232 "giscanner/scannerlexer.l"
{ return REGISTER; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 233 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 234 "giscanner/scannerlexer.l"
{ return RETURN; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 235 "giscanner/scannerlexer.l"
{ return SHORT; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 236 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 237 "giscanner/scannerlexer.l"
{ return SIZEOF; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 238 "giscanner/scannerlexer.l"
{ return STATIC; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 239 "giscanner/scannerlexer.l"
{ return STRUCT; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 240 "giscanner/scannerlexer.l"
{ return SWITCH; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 241 "giscanner/scannerlexer.l"
{ return TYPEDEF; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 242 "giscanner/scannerlexer.l"
{ return UNION; }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 243 "giscanner/scannerlexer.l"
{ return UNSIGNED; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 244 "giscanner/scannerlexer.l"
{ return VOID; }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 245 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 246 "giscanner/scannerlexer.l"
{ return WHILE; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 248 "giscanner/scannerlexer.l"
{ return check_identifier(scanner, yytext); }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 250 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 251 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 252 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 254 "giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 255 "giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 155:
/* rule 155 can match eol */
YY_RULE_SETUP
#line 257 "giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 156:
/* rule 156 can match eol */
YY_RULE_SETUP
#line 258 "giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 157:
/* rule 157 can match eol */
YY_RULE_SETUP
#line 260 "giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 158:
/* rule 158 can match eol */
YY_RULE_SETUP
#line 261 "giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 263 "giscanner/scannerlexer.l"
{ print_error(scanner); }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 265 "giscanner/scannerlexer.l"
ECHO;
	YY_BREAK
#line 2271 "scannerlexer.c"
			case YY_STATE_EOF(INITIAL):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 701 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    
	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 701 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
	yy_is_jam = (yy_current_state == 700);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,(int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (yyconst char* msg )
{
			(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 265 "giscanner/scannerlexer.l"



static int
yywrap (void)
{
  return 1;
}

static void
parse_comment (GISourceScanner *scanner)
{
  int c1, c2;
  GString *string = NULL;
  GISourceComment *comment;
  int comment_lineno;
  int skip = FALSE;

  c1 = input();
  c2 = input();

  if (c2 != IS_EOF && (c1 == '*' && c2 != '*' && c2 != '/')) {
    /*
     * Store GTK-Doc comment blocks,
     * starts with one '/' followed by exactly two '*' and not followed by a '/'
     */
    if (!g_hash_table_contains (scanner->files, scanner->current_file)) {
        skip = TRUE;
    } else {
        string = g_string_new (yytext);
    }

    comment_lineno = lineno;

    while (c2 != IS_EOF && !(c1 == '*' && c2 == '/'))
      {
        if (!skip)
          g_string_append_c (string, c1);

        if (c1 == '\n')
          lineno++;

        c1 = c2;
        c2 = input();
      }

    if (skip) {
        return;
    }

    g_string_append (string, "*/");

    comment = g_slice_new (GISourceComment);
    comment->comment = g_string_free (string, FALSE);
    comment->line = comment_lineno;
    comment->filename = g_file_get_parse_name (scanner->current_file);

    gi_source_scanner_take_comment (scanner, comment);
  } else {
    /*
     * Ignore all other comment blocks
     */
    while (c2 != IS_EOF && !(c1 == '*' && c2 == '/'))
      {
        if (c1 == '\n')
          lineno++;

        c1 = c2;
        c2 = input();
      }

    return;
  }
}

static int
check_identifier (GISourceScanner *scanner,
		  const char  *s)
{
	/*
	 * This function checks if `s' is a type name or an
	 * identifier.
	 */

	if (gi_source_scanner_is_typedef (scanner, s)) {
		return TYPEDEF_NAME;
	} else if (strcmp (s, "__builtin_va_list") == 0) {
		return TYPEDEF_NAME;
	}

	return IDENTIFIER;
}

/* taken from glib/gfileutils.c */
#if defined(MAXPATHLEN)
#define G_PATH_LENGTH MAXPATHLEN
#elif defined(PATH_MAX)
#define G_PATH_LENGTH PATH_MAX
#elif defined(_PC_PATH_MAX)
#define G_PATH_LENGTH sysconf(_PC_PATH_MAX)
#else
#define G_PATH_LENGTH 2048
#endif

static inline char *
_realpath (const char *path)
{
#ifndef _WIN32
  char buffer[G_PATH_LENGTH];

  return realpath (path, buffer) ? g_strdup (buffer) : NULL;
#else
  /* We don't want to include <windows.h> as it clashes horribly
   * with token names from scannerparser.h. So just declare
   * GetFullPathNameA() here unless we already defined it, like
   * in giscanner.c.
   */
#ifndef USE_WINDOWS
  extern __stdcall GetFullPathNameA(const char*, int, char*, char**);
#endif
  char *buffer;
  char dummy;
  int rc, len;

  rc = GetFullPathNameA (path, 1, &dummy, NULL);
  if (rc == 0)
    {
      /* Weird failure, so just return the input path as such */
      return g_strdup (path);
    }

  len = rc + 1;
  buffer = g_malloc (len);

  rc = GetFullPathNameA (path, len, buffer, NULL);
  if (rc == 0 || rc > len)
    {
      /* Weird failure again */
      g_free (buffer);
      return g_strdup (path);
    }
  return buffer;
#endif
}

/*
 * # linenum "filename" flags
 *  See http://gcc.gnu.org/onlinedocs/cpp/Preprocessor-Output.html
 **/

static void
process_linemarks (GISourceScanner *scanner, gboolean has_line)
{
	char escaped_filename[1025];
	char *filename;
	char *real;

	if (has_line)
		sscanf(yytext, "#line %d \"%1024[^\"]\"", &lineno, escaped_filename);
	else
		sscanf(yytext, "# %d \"%1024[^\"]\"", &lineno, escaped_filename);

	filename = g_strcompress (escaped_filename);

        real = _realpath (filename);
        if (real)
          {
            g_free (filename);
            filename = real;
          }

        if (scanner->current_file)
          g_object_unref (scanner->current_file);
	scanner->current_file = g_file_new_for_path (filename);
	g_free (filename);
}

/*
 * This parses a macro which is ignored, such as
 * __attribute__((x)) or __asm__ (x)
 */
static int
parse_ignored_macro (void)
{
	int c;
	int nest;

	while ((c = input ()) != IS_EOF && isspace (c))
		;
	if (c != '(')
		return FALSE;

	nest = 0;
	while ((c = input ()) != IS_EOF && (nest > 0 || c != ')')) {
		if (c == '(')
			nest++;
		else if (c == ')')
			nest--;
		else if (c == '"') {
			while ((c = input ()) != IS_EOF && c != '"') {
				if (c == '\\')
					c = input ();
			}
		} else if (c == '\'') {
			c = input ();
			if (c == '\\')
				c = input ();
			else if (c == '\'')
				return FALSE;
			c = input ();
			if (c != '\'')
				return FALSE;
		} else if (c == '\n')
			lineno++;
	}

	return TRUE;
}

static void
parse_trigraph (GISourceScanner *scanner)
{
	char **items;
	char *start, *end;
	int i;

	start = g_strstr_len (yytext, yyleng, "<");
	g_assert (start != NULL);
	end = g_strstr_len (yytext, yyleng, ">");
	g_assert (end != NULL);
	*end = '\0';
	items = g_strsplit (start + 1, ",", 0);
	for (i = 0; items[i] != NULL; i++) {
		char *item = items[i];
		g_strstrip (item);
		if (strcmp (item, "public") == 0)
			scanner->private = FALSE;
		else if (strcmp (item, "private") == 0)
			scanner->private = TRUE;
		else if (strcmp (item, "flags") == 0)
			scanner->flags = TRUE;
	}
	g_strfreev (items);
}

static void
print_error (GISourceScanner *scanner)
{
  if (yytext[0]) {
    char *filename = g_file_get_parse_name (scanner->current_file);
    fprintf(stderr, "%s:%d: unexpected character `%c'\n", filename, lineno, yytext[0]);
    g_free (filename);
  }
}

